package com.cm6123.monopoly.game;

import java.util.HashMap;

/**
 * Class for the board for the game using hashmaps.
 */
public class Board {
    // Using a hashmap from w3schools.com/java/java_hashmap.asp
    /**
     * Calibrating hashmap with positions and tile names.
     */
    private static final HashMap<Integer, String> GAME_BOARD = new HashMap<>();

    /**
     * HashMap with the properties on them so that when a player buys the property it'll be noticed.
     */
    private static final HashMap<Integer, Boolean> PROPERTY_OWNERSHIP = new HashMap<>();

    /**
     * Constructor for the board.
     */
    public Board() {
        createGameBoard();
        propertyBoard();
    }

    /**
     * Hashmap with all the tile names and theire positions.
     */
    private void createGameBoard() {
        GAME_BOARD.put(1, "Home");
        GAME_BOARD.put(2, "Road");
        GAME_BOARD.put(3, "Road");
        GAME_BOARD.put(4, "Old Kent Road");
        GAME_BOARD.put(5, "Pall Mall");
        GAME_BOARD.put(6, "Road");
        GAME_BOARD.put(7, "Paddington");
        GAME_BOARD.put(8, "Road");
        GAME_BOARD.put(9, "The Strand");
        GAME_BOARD.put(10, "Road");
        GAME_BOARD.put(11, "Tax Office");
        GAME_BOARD.put(12, "Waterloo");
        GAME_BOARD.put(13, "Leicester Square");
        GAME_BOARD.put(14, "Road");
        GAME_BOARD.put(15, "Park Lane");
        GAME_BOARD.put(16, "Road");
    }

    /**
     * Properties on the board are initialy false so when a player buys the property itll become true.
     */
    private void propertyBoard() {
        PROPERTY_OWNERSHIP.put(4, false);
        PROPERTY_OWNERSHIP.put(5, false);
        PROPERTY_OWNERSHIP.put(9, false);
        PROPERTY_OWNERSHIP.put(13, false);
        PROPERTY_OWNERSHIP.put(15, false);
    }

    /**
     * Gets the board hashmap.
     *
     * @return the hashmap representing the game board
     */
    public static HashMap<Integer, String> getGameBoard() {
        return GAME_BOARD;
    }

    /**
     * Gets the names of the tiles and their positions.
     *
     * @param position the position of the tile
     * @return the name of the tile at the position
     */
    public String getGameBoard(final int position) {
        return GAME_BOARD.get(position);
    }

    /**
     * Checks if a property can be purchased by the current player if they land on it.
     *
     * @param position the position of the property
     * @return true if the property can be purchased; false otherwise.
     */
    public boolean canBuyProperty(final int position) {
        return PROPERTY_OWNERSHIP.containsKey(position) && !PROPERTY_OWNERSHIP.get(position);
    }

    /**
     * If a player decides to purchase a property then 200 will be taken away from the players bank account.
     * The posisiton/property they just bought will become true so now other players cannot purchase the same property.
     *
     * @param position the position of the property to be purchased
     * @param player the player buying the property
     */
    public void buyProperty(final int position,final Player player) {
        if (canBuyProperty(position)) {
            String propertyName = getGameBoard(position);
            Properties property = new Properties(propertyName);
            player.subtractMoney(property.getPrice());
            PROPERTY_OWNERSHIP.put(position, true);
            property.setOwner(player);

            Player propertyOwner = property.getOwner();

            System.out.println(propertyOwner.getName() + " has bought this property.");
            System.out.println("You now have £" + player.getMoney() + " in your bank account.");
        }
    }
}
