package com.cm6123.monopoly.game;

import java.util.Scanner;

/**
 * class for game actions if a player lands on a tile that is useful.
 */
public class GameAction implements GameHandler {

    /**
     * The board.
     */
    private final Board board;


    /**
     * Constructor for GameAction with the board.
     *
     * @param gameboard the board used for game actions
     */
    public GameAction(final Board gameboard) {
        this.board = gameboard;
    }

    /**
     * Game action if a player lands on a property.
     *
     * @param player the player who landed on the property
     */
    @Override
    public void landedOnProperty(final Player player) {
        int position = player.getPosition();

        // Check if the property at the current position can be bought
        if (this.board.canBuyProperty(position)) {
            String propertyName = this.board.getGameBoard(position);
            System.out.println("Would you like to buy " + propertyName + " for £200? (Y/N)");

            Scanner scanner = new Scanner(System.in);
            String input = scanner.next().toUpperCase();

            // if Player chooses to buy the property check if the player has enough to buy it
            if (input.equals("Y")) {
                if (player.getMoney() >= 200) {
                    this.board.buyProperty(position, player);
                } else {
                    System.out.println("You do not have enough money to buy " + propertyName + ". Moving on...");
                } // if player doesn't want to buy it move on
            } else if (input.equals("N")) {
                System.out.println("You have chosen N, moving on...");
            } else { // if user enters something else skip the turn
                System.out.println("Invalid input. Skipping turn");
            }
        }
    }
}
